Struct oursh::program::posix::builtin::Dot [−][src]
pub struct Dot;
Execute commands from file in the current environment
TODO:
If file does not contain a /, the shell shall use the search path
specified by PATH to find the directory containing file. Unlike normal
command search, however, the file searched for by the . utility need not
be executable. If no readable file is found, a non-interactive shell shall
abort; an interactive shell shall write a diagnostic message to standard
error, but this condition shall not be considered a syntax error.