Trait oursh::program::posix::builtin::Builtin [−][src]
pub trait Builtin {
fn run(
self,
argv: Vec<CString>,
runtime: &mut Runtime<'_>
) -> Result<WaitStatus>;
}Expand description
A builtin is a custom shell command, often changing the state of the shell in some way.